function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var Echarts = _interopDefault(require('echarts/lib/echarts'));
require('echarts/lib/component/axisPointer');
require('echarts/lib/component/grid');
require('echarts/lib/component/legend');
require('echarts/lib/component/legendScroll');
require('echarts/lib/chart/bar');
require('echarts/lib/chart/line');
require('echarts/lib/chart/radar');
require('echarts/lib/chart/scatter');
require('echarts/lib/chart/gauge');
require('echarts/lib/chart/pie');
require('echarts/lib/component/title');
require('echarts/lib/component/toolbox');
require('echarts/lib/component/tooltip');
require('echarts/lib/component/graphic');
require('echarts/lib/component/dataZoom');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;
  subClass.__proto__ = superClass;
}

var EchartsOptionContext = React.createContext({
  setOptions: function setOptions() {},
  updateOption: function updateOption() {}
});
var EchartsEventContext = React.createContext({
  onEvent: function onEvent() {},
  offEvent: function offEvent() {}
});

var ChartComponent;

(function (ChartComponent) {
  ChartComponent["Title"] = "title";
  ChartComponent["Grid"] = "grid";
  ChartComponent["Legend"] = "legend";
  ChartComponent["Tooltip"] = "tooltip";
  ChartComponent["Series"] = "series";
  ChartComponent["XAxis"] = "xAxis";
  ChartComponent["YAxis"] = "yAxis";
  ChartComponent["AxisPointer"] = "axisPointer";
  ChartComponent["Toolbox"] = "toolbox";
  ChartComponent["Graphic"] = "graphic";
  ChartComponent["DataZoom"] = "dataZoom";
  ChartComponent["Bar"] = "bar";
  ChartComponent["Line"] = "line";
  ChartComponent["LineAndBar"] = "lineAndBar";
})(ChartComponent || (ChartComponent = {}));

var ECHARTS_STYLE = {
  height: '100%',
  width: '100%'
};

var EchartsReactCore = /*#__PURE__*/function (_Component) {
  _inheritsLoose(EchartsReactCore, _Component);

  function EchartsReactCore(props) {
    var _this;

    _this = _Component.call(this, props) || this;

    _this.setOption = function (options) {
      console.log(options);
    };

    _this.updateOption = function (options, componentKey) {
      if (_this.options[componentKey] === options) {
        console.log("Component " + componentKey + " not changed");
        return;
      }

      if (componentKey === ChartComponent.XAxis || componentKey === ChartComponent.YAxis) {
        var optionValue = options[componentKey];

        if (Array.isArray(optionValue)) {
          options[componentKey] = optionValue.map(function (option) {
            return _extends({}, option, {
              show: option.show !== false
            });
          });
        } else {
          options[componentKey] = _extends({}, optionValue, {
            show: options.show !== false
          });
        }
      }

      console.log('====================================');
      console.log(options);
      console.log('====================================');
      _this.options = _extends({}, _this.options, options);

      var _this$props = _this.props,
          notMerge = _this$props.notMerge,
          lazyUpdate = _this$props.lazyUpdate;

      _this.echartsLib.setOption(_this.options, notMerge, lazyUpdate);
    };

    _this.onEvent = function (params) {
      var type = params.type,
          handler = params.handler;

      _this.echartsLib.on(type, handler);
    };

    _this.offEvent = function (params) {
      var type = params.type,
          handler = params.handler;

      _this.echartsLib.off(type, handler);
    };

    _this.echartsElementRef = React.createRef();
    _this.options = _extends({
      xAxis: {
        show: false
      },
      yAxis: {
        show: false
      },
      series: []
    }, props.options || {});
    _this.state = {
      optionHandler: {
        setOptions: _this.setOption,
        updateOption: _this.updateOption
      },
      eventHandler: {
        onEvent: _this.onEvent,
        offEvent: _this.offEvent
      }
    };
    return _this;
  }

  var _proto = EchartsReactCore.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var _this2 = this;

    this.echartsLib = Echarts.init(this.echartsElementRef.current, this.options);
    var _this$props2 = this.props,
        lazyUpdate = _this$props2.lazyUpdate,
        notMerge = _this$props2.notMerge,
        showLoading = _this$props2.showLoading,
        loadingType = _this$props2.loadingType,
        loadingOption = _this$props2.loadingOption,
        resize = _this$props2.resize,
        resizeOption = _this$props2.resizeOption;
    this.echartsLib.setOption(this.options, notMerge, lazyUpdate);

    if (showLoading) {
      this.echartsLib.showLoading(loadingType, loadingOption);
    }

    if (resize) {
      window.onresize = function () {
        _this2.echartsLib.resize(resizeOption);
      };
    }
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    var _this$props3 = this.props,
        options = _this$props3.options,
        notMerge = _this$props3.notMerge,
        lazyUpdate = _this$props3.lazyUpdate,
        showLoading = _this$props3.showLoading,
        loadingType = _this$props3.loadingType,
        loadingOption = _this$props3.loadingOption;

    if (prevProps.options !== options) {
      this.options = _extends({}, this.options, this.props.options);
      this.echartsLib.setOption(this.options, notMerge, lazyUpdate);
    }

    if (prevProps.showLoading === showLoading) {
      return;
    }

    if (showLoading) {
      this.echartsLib.showLoading(loadingType, loadingOption);
    } else {
      this.echartsLib.hideLoading();
    }
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    if (!this.echartsLib.isDisposed()) {
      this.echartsLib.dispose();
    }
  };

  _proto.render = function render() {
    var _this$props4 = this.props,
        _this$props4$classNam = _this$props4.className,
        className = _this$props4$classNam === void 0 ? '' : _this$props4$classNam,
        children = _this$props4.children;
    var _this$state = this.state,
        optionHandler = _this$state.optionHandler,
        eventHandler = _this$state.eventHandler;
    return React__default.createElement(EchartsOptionContext.Provider, {
      value: optionHandler
    }, React__default.createElement(EchartsEventContext.Provider, {
      value: eventHandler
    }, React__default.createElement("div", {
      style: ECHARTS_STYLE,
      ref: this.echartsElementRef,
      className: "echarts-for-react " + className
    }), children));
  };

  return EchartsReactCore;
}(React.Component);

function useOption(option, componentType, subType) {
  var _useContext = React.useContext(EchartsOptionContext),
      updateOption = _useContext.updateOption;

  React.useEffect(function () {
    var _partialOption;

    var partialOption = (_partialOption = {}, _partialOption[componentType] = option.options, _partialOption);
    updateOption(partialOption, componentType, subType);
  }, [option]);
}

function AxisPointer(options) {
  useOption(options, ChartComponent.AxisPointer);
  return null;
}

function Grid(options) {
  useOption(options, ChartComponent.Grid);
  return null;
}

function Legend(options) {
  useOption(options, ChartComponent.Legend);
  return null;
}

function SeriesBar(options) {
  useOption(options, ChartComponent.Series, ChartComponent.Bar);
  return null;
}

function SeriesLine(options) {
  useOption(options, ChartComponent.Series, ChartComponent.Line);
  return null;
}

function SeriesLineAndBar(options) {
  useOption(options, ChartComponent.Series, ChartComponent.LineAndBar);
  return null;
}

function SeriesRadar(options) {
  useOption(options, ChartComponent.Series);
  return null;
}

function SeriesScatter(options) {
  useOption(options, ChartComponent.Series);
  return null;
}

function SeriesGauge(options) {
  useOption(options, ChartComponent.Series);
  return null;
}

function SeriesPie(options) {
  useOption(options, ChartComponent.Series);
  return null;
}

function Title(options) {
  useOption(options, ChartComponent.Title);
  return null;
}

function Toolbox(options) {
  useOption(options, ChartComponent.Toolbox);
  return null;
}

function Tooltip(options) {
  useOption(options, ChartComponent.Tooltip);
  return null;
}

function XAxis(options) {
  useOption(options, ChartComponent.XAxis);
  return null;
}

function YAxis(options) {
  useOption(options, ChartComponent.YAxis);
  return null;
}

function Graphic(options) {
  useOption(options, ChartComponent.Graphic);
  return null;
}

function DataZoom(options) {
  useOption(options, ChartComponent.DataZoom);
  return null;
}

function Event(props) {
  var _useContext = React.useContext(EchartsEventContext),
      onEvent = _useContext.onEvent,
      offEvent = _useContext.offEvent;

  React.useEffect(function () {
    offEvent(props);
    onEvent(props);
    return function () {
      offEvent(props);
    };
  }, [props]);
  return null;
}

var index = React.memo(Event);

exports.AxisPointer = AxisPointer;
exports.DataZoom = DataZoom;
exports.Echart = EchartsReactCore;
exports.Event = index;
exports.Graphic = Graphic;
exports.Grid = Grid;
exports.Legend = Legend;
exports.SeriesBar = SeriesBar;
exports.SeriesGauge = SeriesGauge;
exports.SeriesLine = SeriesLine;
exports.SeriesLineAndBar = SeriesLineAndBar;
exports.SeriesPie = SeriesPie;
exports.SeriesRadar = SeriesRadar;
exports.SeriesScatter = SeriesScatter;
exports.Title = Title;
exports.Toolbox = Toolbox;
exports.Tooltip = Tooltip;
exports.XAxis = XAxis;
exports.YAxis = YAxis;
//# sourceMappingURL=index.js.map
